==> hplip-0.9.5-i586-4vl5.tgz: install/doinst.sh <==
#!/bin/sh
( cd ./usr/bin ; rm -rf hp-makeuri )
( cd ./usr/bin ; ln -sf ../share/hplip/makeuri hp-makeuri )
( cd ./usr/bin ; rm -rf hp-toolbox )
( cd ./usr/bin ; ln -sf ../share/hplip/toolbox hp-toolbox )
( cd ./usr/bin ; rm -rf hp-levels )
( cd ./usr/bin ; ln -sf ../share/hplip/levels hp-levels )
( cd ./usr/bin ; rm -rf hp-testpage )
( cd ./usr/bin ; ln -sf ../share/hplip/testpage hp-testpage )
( cd ./usr/bin ; rm -rf hp-unload )
( cd ./usr/bin ; ln -sf ../share/hplip/unload hp-unload )
( cd ./usr/bin ; rm -rf hp-colorcal )
( cd ./usr/bin ; ln -sf ../share/hplip/colorcal hp-colorcal )
( cd ./usr/bin ; rm -rf hp-fab )
( cd ./usr/bin ; ln -sf ../share/hplip/fab hp-fab )
( cd ./usr/bin ; rm -rf hp-info )
( cd ./usr/bin ; ln -sf ../share/hplip/info hp-info )
( cd ./usr/bin ; rm -rf hp-align )
( cd ./usr/bin ; ln -sf ../share/hplip/align hp-align )
( cd ./usr/bin ; rm -rf hp-check )
( cd ./usr/bin ; ln -sf ../share/hplip/check hp-check )
( cd ./usr/bin ; rm -rf hp-clean )
( cd ./usr/bin ; ln -sf ../share/hplip/clean hp-clean )
( cd ./usr/bin ; rm -rf hp-photo )
( cd ./usr/bin ; ln -sf ../share/hplip/photo hp-photo )
( cd ./usr/bin ; rm -rf hp-print )
( cd ./usr/bin ; ln -sf ../share/hplip/print hp-print )
( cd ./usr/bin ; rm -rf hp-probe )
( cd ./usr/bin ; ln -sf ../share/hplip/probe hp-probe )
( cd ./usr/lib/cups/filter ; rm -rf foomatic-rip )
( cd ./usr/lib/cups/filter ; ln -sf /usr/bin/foomatic-rip foomatic-rip )
( cd ./usr/lib/menu ; rm -rf hplip )
( cd ./usr/lib/menu ; ln -sf /usr/share/hplip/data/hplip hplip )
( cd ./usr/lib/sane ; rm -rf libsane-hpaio.so )
( cd ./usr/lib/sane ; ln -sf ../libsane-hpaio.so.1.0.0 libsane-hpaio.so )
( cd ./usr/lib/sane ; rm -rf libsane-hpaio.so.1 )
( cd ./usr/lib/sane ; ln -sf ../libsane-hpaio.so.1.0.0 libsane-hpaio.so.1 )
( cd ./usr/lib/sane ; rm -rf libsane-hpaio.so.1.0.0 )
( cd ./usr/lib/sane ; ln -sf ../libsane-hpaio.so.1.0.0 libsane-hpaio.so.1.0.0 )
( cd ./usr/lib ; rm -rf libsane-hpaio.so )
( cd ./usr/lib ; ln -sf libsane-hpaio.so.1.0.0 libsane-hpaio.so )
( cd ./usr/lib ; rm -rf libhpip.so )
( cd ./usr/lib ; ln -sf libhpip.so.0.0.1 libhpip.so )
( cd ./usr/lib ; rm -rf libhpip.so.0 )
( cd ./usr/lib ; ln -sf libhpip.so.0.0.1 libhpip.so.0 )
( cd ./usr/lib ; rm -rf libsane-hpaio.so.1 )
( cd ./usr/lib ; ln -sf libsane-hpaio.so.1.0.0 libsane-hpaio.so.1 )
( cd ./usr/share ; rm -rf doc )
( cd ./usr/share ; ln -sf ../doc doc )
( cd ./usr/share/cups/model ; rm -rf foomatic-ppds )
( cd ./usr/share/cups/model ; ln -sf /usr/share/ppd foomatic-ppds )

# add creation of symlinks to hplip script in /etc/rc.d run levels
# hplip must start before cups and end after cups in init sequence

( cd /etc/rc.d/rc2.d ; rm -f *hplip ; ln -sf ../init.d/hplip S38hplip ; ln -sf ../init.d/hplip K61hplip )
( cd /etc/rc.d/rc3.d ; rm -f *hplip ; ln -sf ../init.d/hplip S38hplip ; ln -sf ../init.d/hplip K61hplip )
( cd /etc/rc.d/rc4.d ; rm -f *hplip ; ln -sf ../init.d/hplip S38hplip ; ln -sf ../init.d/hplip K61hplip )
( cd /etc/rc.d/rc5.d ; rm -f *hplip ; ln -sf ../init.d/hplip S38hplip ; ln -sf ../init.d/hplip K61hplip )

# initialize hplip and restart CUPS

( echo "Initialising hplip..." ; /etc/rc.d/init.d/hplip restart )
( echo "Restarting CUPS..." ; /etc/rc.d/init.d/cups restart )

==> hplip-0.9.9-i586-4vl5.tgz: install/doinst.sh <==
#!/bin/sh
( cd ./usr/bin ; rm -rf hp-makeuri )
( cd ./usr/bin ; ln -sf ../share/hplip/makeuri hp-makeuri )
( cd ./usr/bin ; rm -rf hp-toolbox )
( cd ./usr/bin ; ln -sf ../share/hplip/toolbox hp-toolbox )
( cd ./usr/bin ; rm -rf hp-levels )
( cd ./usr/bin ; ln -sf ../share/hplip/levels hp-levels )
( cd ./usr/bin ; rm -rf hp-testpage )
( cd ./usr/bin ; ln -sf ../share/hplip/testpage hp-testpage )
( cd ./usr/bin ; rm -rf hp-unload )
( cd ./usr/bin ; ln -sf ../share/hplip/unload hp-unload )
( cd ./usr/bin ; rm -rf hp-colorcal )
( cd ./usr/bin ; ln -sf ../share/hplip/colorcal hp-colorcal )
( cd ./usr/bin ; rm -rf hp-fab )
( cd ./usr/bin ; ln -sf ../share/hplip/fab hp-fab )
( cd ./usr/bin ; rm -rf hp-info )
( cd ./usr/bin ; ln -sf ../share/hplip/info hp-info )
( cd ./usr/bin ; rm -rf hp-align )
( cd ./usr/bin ; ln -sf ../share/hplip/align hp-align )
( cd ./usr/bin ; rm -rf hp-check )
( cd ./usr/bin ; ln -sf ../share/hplip/check hp-check )
( cd ./usr/bin ; rm -rf hp-clean )
( cd ./usr/bin ; ln -sf ../share/hplip/clean hp-clean )
( cd ./usr/bin ; rm -rf hp-photo )
( cd ./usr/bin ; ln -sf ../share/hplip/photo hp-photo )
( cd ./usr/bin ; rm -rf hp-print )
( cd ./usr/bin ; ln -sf ../share/hplip/print hp-print )
( cd ./usr/bin ; rm -rf hp-setup )
( cd ./usr/bin ; ln -sf ../share/hplip/setup hp-setup )
( cd ./usr/bin ; rm -rf hp-sendfax )
( cd ./usr/bin ; ln -sf ../share/hplip/sendfax hp-sendfax )
( cd ./usr/lib/cups/filter ; rm -rf foomatic-rip )
( cd ./usr/lib/cups/filter ; ln -sf /usr/bin/foomatic-rip foomatic-rip )
( cd ./usr/lib/sane ; rm -rf libsane-hpaio.so )
( cd ./usr/lib/sane ; ln -sf ../libsane-hpaio.so.1.0.0 libsane-hpaio.so )
( cd ./usr/lib/sane ; rm -rf libsane-hpaio.so.1 )
( cd ./usr/lib/sane ; ln -sf ../libsane-hpaio.so.1.0.0 libsane-hpaio.so.1 )
( cd ./usr/lib/sane ; rm -rf libsane-hpaio.so.1.0.0 )
( cd ./usr/lib/sane ; ln -sf ../libsane-hpaio.so.1.0.0 libsane-hpaio.so.1.0.0 )
( cd ./usr/lib ; rm -rf libsane-hpaio.so )
( cd ./usr/lib ; ln -sf libsane-hpaio.so.1.0.0 libsane-hpaio.so )
( cd ./usr/lib ; rm -rf libhpip.so )
( cd ./usr/lib ; ln -sf libhpip.so.0.0.1 libhpip.so )
( cd ./usr/lib ; rm -rf libhpip.so.0 )
( cd ./usr/lib ; ln -sf libhpip.so.0.0.1 libhpip.so.0 )
( cd ./usr/lib ; rm -rf libsane-hpaio.so.1 )
( cd ./usr/lib ; ln -sf libsane-hpaio.so.1.0.0 libsane-hpaio.so.1 )
( cd ./usr/share/cups/model ; rm -rf foomatic-ppds )
( cd ./usr/share/cups/model ; ln -sf /usr/share/ppd foomatic-ppds )

#!/bin/sh

# add creation of symlinks to hplip script in /etc/rc.d run levels
# hplip must start before cups and end after cups in init sequence

( cd /etc/rc.d/rc2.d ; rm -f *hplip ; ln -sf ../init.d/hplip S38hplip ; ln -sf ../init.d/hplip K61hplip )
( cd /etc/rc.d/rc3.d ; rm -f *hplip ; ln -sf ../init.d/hplip S38hplip ; ln -sf ../init.d/hplip K61hplip )
( cd /etc/rc.d/rc4.d ; rm -f *hplip ; ln -sf ../init.d/hplip S38hplip ; ln -sf ../init.d/hplip K61hplip )
( cd /etc/rc.d/rc5.d ; rm -f *hplip ; ln -sf ../init.d/hplip S38hplip ; ln -sf ../init.d/hplip K61hplip )

# initialize hplip and restart CUPS

( echo "Initialising hplip..." ; /etc/rc.d/init.d/hplip restart )
( echo "Restarting CUPS..." ; /etc/rc.d/init.d/cups restart )
